summaryrefslogtreecommitdiffstats
path: root/net/http/http_cache.cc
diff options
context:
space:
mode:
Diffstat (limited to 'net/http/http_cache.cc')
-rw-r--r--net/http/http_cache.cc16
1 files changed, 8 insertions, 8 deletions
diff --git a/net/http/http_cache.cc b/net/http/http_cache.cc
index 91ba1f3..9a23aab 100644
--- a/net/http/http_cache.cc
+++ b/net/http/http_cache.cc
@@ -88,7 +88,7 @@ HttpCache::BackendFactory* HttpCache::DefaultBackend::InMemory(int max_bytes) {
int HttpCache::DefaultBackend::CreateBackend(NetLog* net_log,
disk_cache::Backend** backend,
- CompletionCallback* callback) {
+ OldCompletionCallback* callback) {
DCHECK_GE(max_bytes_, 0);
return disk_cache::CreateCacheBackend(type_, path_, max_bytes_, true,
thread_, net_log, backend, callback);
@@ -121,7 +121,7 @@ struct HttpCache::PendingOp {
disk_cache::Entry* disk_entry;
disk_cache::Backend* backend;
WorkItem* writer;
- CompletionCallback* callback; // BackendCallback.
+ OldCompletionCallback* callback; // BackendCallback.
WorkItemList pending_queue;
};
@@ -143,7 +143,7 @@ class HttpCache::WorkItem {
: operation_(operation), trans_(trans), entry_(entry), callback_(NULL),
backend_(NULL) {}
WorkItem(WorkItemOperation operation, Transaction* trans,
- CompletionCallback* cb, disk_cache::Backend** backend)
+ OldCompletionCallback* cb, disk_cache::Backend** backend)
: operation_(operation), trans_(trans), entry_(NULL), callback_(cb),
backend_(backend) {}
~WorkItem() {}
@@ -180,13 +180,13 @@ class HttpCache::WorkItem {
WorkItemOperation operation_;
Transaction* trans_;
ActiveEntry** entry_;
- CompletionCallback* callback_; // User callback.
+ OldCompletionCallback* callback_; // User callback.
disk_cache::Backend** backend_;
};
//-----------------------------------------------------------------------------
// This class is a specialized type of CompletionCallback that allows us to
// pass multiple arguments to the completion routine.
class HttpCache::BackendCallback : public CallbackRunner<Tuple1<int> > {
public:
@@ -241,7 +241,7 @@ class HttpCache::MetadataWriter {
scoped_refptr<IOBuffer> buf_;
int buf_len_;
base::Time expected_response_time_;
- CompletionCallbackImpl<MetadataWriter> callback_;
+ OldCompletionCallbackImpl<MetadataWriter> callback_;
HttpRequestInfo request_info_;
DISALLOW_COPY_AND_ASSIGN(MetadataWriter);
};
@@ -420,7 +420,7 @@ HttpCache::~HttpCache() {
}
int HttpCache::GetBackend(disk_cache::Backend** backend,
- CompletionCallback* callback) {
+ OldCompletionCallback* callback) {
DCHECK(callback != NULL);
if (disk_cache_.get()) {
@@ -510,7 +510,7 @@ HttpNetworkSession* HttpCache::GetSession() {
//-----------------------------------------------------------------------------
int HttpCache::CreateBackend(disk_cache::Backend** backend,
- CompletionCallback* callback) {
+ OldCompletionCallback* callback) {
if (!backend_factory_.get())
return ERR_FAILED;
@@ -180,13 +180,13 @@ class HttpCache::WorkItem {
};
//-----------------------------------------------------------------------------
-// This class is a specialized type of CompletionCallback that allows us to
+// This class is a specialized type of OldCompletionCallback that allows us to
// pass multiple arguments to the completion routine.
class HttpCache::BackendCallback : public CallbackRunner<Tuple1<int> > {